@@ -172,6 +172,19 @@ impl RgbImage {
         &self.bands[band]
     }
 
+    pub fn set_band(&mut self, buffer:&ImageBuffer, band:usize) {
+        if self.bands.len() <= band {
+            panic!("Invalid band specified");
+        }
+
+        self.bands[band] = buffer.clone();
+    }
+
+    pub fn push_band(&mut self, buffer:&ImageBuffer) -> usize {
+        self.bands.push(buffer.clone());
+        self.num_bands()
+    }
+
     pub fn divide_from_each(&mut self, other:&ImageBuffer) {
         if self.width != other.width || self.height != other.height {
             panic!("Array size mismatch");
@@ -503,6 +516,7 @@ impl RgbImage {
     pub fn normalize_to_8bit_with_max(&mut self, max:f32) {
         for i in 0..self.bands.len() {
             self.bands[i] = self.bands[i].normalize_force_minmax(0.0, 255.0, 0.0, max).unwrap();
+            self.bands[i].clip_mut(0.0, 255.0);
         }
         self.mode = enums::ImageMode::U8BIT;
     }
@@ -517,6 +531,7 @@ impl RgbImage {
     pub fn normalize_to_16bit_with_max(&mut self, max:f32) {
         for i in 0..self.bands.len() {
             self.bands[i] = self.bands[i].normalize_force_minmax(0.0, 65535.0, 0.0, max).unwrap();
+            self.bands[i].clip_mut(0.0, 65535.0);
         }
         self.mode = enums::ImageMode::U16BIT;
     }
